# yaq-traits

[![PyPI](https://img.shields.io/pypi/v/yaq-traits)](https://pypi.org/project/yaq-traits)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaq-traits)](https://anaconda.org/conda-forge/yaq-traits)
[![yaq](https://img.shields.io/badge/framework-yaq-orange)](https://yaq.fyi/)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)
[![ver](https://img.shields.io/badge/calver-YYYY.M.MICRO-blue)](https://calver.org/)
[![log](https://img.shields.io/badge/change-log-informational)](https://gitlab.com/yaq/yaq-traits/-/blob/master/CHANGELOG.md)

package defining yaq traits
